Module program

Module program 

Structs

InstructionIter
An InstructionIter loops the instructions of a Program by skipping duplicate placeholders.
Program
A Program is a Vec<Instruction> that contains duplicate elements for instructions with a size of 2. This means that the index in the vector corresponds to the VM’s instruction_pointer. These duplicate values should most often be skipped/ignored, e.g. when pretty-printing.