Program

Struct Program 

pub struct Program {
    pub instructions: Vec<Instruction>,
}
A Program is a Vec<Instruction> that contains duplicate elements for instructions with a size of 2. This means that the index in the vector corresponds to the VM’s instruction_pointer. These duplicate values should most often be skipped/ignored, e.g. when pretty-printing.

Fields

instructions: Vec<Instruction>

Implementations

Source

impl Program

pub fn new(input: &[LabelledInstruction]) -> Self

Create a Program from a slice of Instruction.

pub fn from_code(code: &str) -> Result<Self>

Create a Program by parsing source code.

pub fn to_bwords(&self) -> Vec<BFieldElement>

Convert a Program to a Vec<BFieldElement>.

Every single-word instruction is converted to a single word.

Every double-word instruction is converted to two words.

pub fn len_bwords(&self) -> usize

The total length of the program as BFieldElements. Double-word instructions contribute two BFieldElements.

pub fn is_empty(&self) -> bool

pub fn hash<H: AlgebraicHasher>(&self) -> Digest

Hash the program using the given AlgebraicHasher.