Structs
- Instruction
Iter - An
InstructionIterloops the instructions of aProgramby skipping duplicate placeholders. - Program
- A
Programis aVec<Instruction>that contains duplicate elements for instructions with a size of 2. This means that the index in the vector corresponds to the VM’sinstruction_pointer. These duplicate values should most often be skipped/ignored, e.g. when pretty-printing.